@@ -13,7 +13,7 @@ func TestAllFunc(t *testing.T) {
 	)
 
 	t.Run(
-		"RootAll",
+		"RootAllSlice",
 		selectTest(
 			"all()",
 			[]interface{}{"red", "green", "blue"},
@@ -21,7 +21,7 @@ func TestAllFunc(t *testing.T) {
 		),
 	)
 	t.Run(
-		"NestedAll",
+		"NestedAllSlice",
 		selectTest(
 			"colours.all()",
 			map[string]interface{}{
@@ -30,4 +30,12 @@ func TestAllFunc(t *testing.T) {
 			[]interface{}{"red", "green", "blue"},
 		),
 	)
+	t.Run(
+		"AllString",
+		selectTest(
+			"all()",
+			"asd",
+			[]interface{}{"a", "s", "d"},
+		),
+	)
 }
