@@ -51,6 +51,30 @@ func TestIndexFunc(t *testing.T) {
 		),
 	)
 
+	t.Run(
+		"IndexString",
+		selectTest(
+			"colours.index(1).index(1)",
+			original,
+			[]interface{}{
+				"r",
+			},
+		),
+	)
+
+	t.Run(
+		"IndexMulti",
+		selectTest(
+			"colours.index(0,1,2)",
+			original,
+			[]interface{}{
+				"red",
+				"green",
+				"blue",
+			},
+		),
+	)
+
 	t.Run(
 		"IndexShorthand",
 		selectTest(
@@ -61,4 +85,17 @@ func TestIndexFunc(t *testing.T) {
 			},
 		),
 	)
+
+	t.Run(
+		"IndexShorthandMulti",
+		selectTest(
+			"colours.[0,1,2]",
+			original,
+			[]interface{}{
+				"red",
+				"green",
+				"blue",
+			},
+		),
+	)
 }
