@@ -25,6 +25,7 @@ func TestTypeFunc(t *testing.T) {
 		"int":   int(1),
 		"float": float32(1),
 		"bool":  true,
+		"null":  nil,
 	}
 
 	t.Run(
@@ -87,4 +88,14 @@ func TestTypeFunc(t *testing.T) {
 			},
 		),
 	)
+	t.Run(
+		"null",
+		selectTest(
+			"null.type()",
+			data,
+			[]interface{}{
+				"null",
+			},
+		),
+	)
 }
